<?php
/**
 * Functions File
 *
 * This is your child theme's functions.php file.  It is here for adding custom functions and 
 * setting up default functionality for this child theme.  You are free to modify this file in
 * any way you like.  Note that if you change the functions already within this file, you run 
 * the risk of losing theme functionality.  Alter the functions below only if you know what
 * you're doing.
 *
 * @package Outline
 * @subpackage Functions
 */

/* Set up the child theme. */
add_action( 'after_setup_theme', 'outline_setup_theme' );

/**
 * Adds all the default actions and filters to their appropriate hooks and sets up anything
 * else needed by the theme.
 *
 * @since 0.1
 */
function outline_setup_theme() {

	/* Get the parent theme prefix for use with its hooks. */
	$prefix = hybrid_get_prefix();

	/* Load any translation files for the user. */
	load_child_theme_textdomain( 'outline', get_stylesheet_directory() . '/languages' );

	/* Allow users to upload a custom background. */
	add_custom_background();

	/* Register additional menus. */
	add_action( 'init', 'outline_register_menus', 11 );

	/* Add the search form after the primary menu. */
	add_action( "{$prefix}_after_primary_menu", 'get_search_form' );

	/* Add the secondary menu before the header. */
	add_action( "{$prefix}_before_header", 'outline_get_secondary_menu' );

	/* Add an author box after singular posts. */
	add_action( "{$prefix}_singular-post_after_singular", 'outline_author_box' );

	/* Disable sidebars on specific page views. */
	add_filter( 'sidebars_widgets', 'outline_disable_sidebars' );

	/* Create additional user contact methods. */
	add_filter( 'user_contactmethods', 'outline_contact_methods' );
}

/**
 * Disables sidebars on when viewing singular attachment pages.
 *
 * @since 0.1
 */
function outline_disable_sidebars( $sidebars_widgets ) {
	if ( is_attachment() ) {
		$sidebars_widgets['primary'] = false;
		$sidebars_widgets['secondary'] = false;
	}

	return $sidebars_widgets;
}

/**
 * Adds new contact information on the edit user screen.
 *
 * @since 0.3
 */
function outline_contact_methods( $meta ) {
	$meta['twitter'] = __( 'Twitter Username', 'outline' );
	return $meta;
}

/**
 * Registers additional menus for the theme.
 *
 * @since 0.1
 */
function outline_register_menus() {
	register_nav_menu( 'secondary-menu', __( 'Secondary Menu', 'outline' ) );
}

/**
 * Secondary menu, which is in the first position.
 *
 * @since 0.1
 */
function outline_get_secondary_menu() {
	locate_template( array( 'menu-secondary.php', 'menu.php' ), true );
}

/**
 * Adds an author box at the end of single posts.
 *
 * @since 0.1
 */
function outline_author_box() { ?>
	<div class="author-profile vcard">

		<h4 class="author-name fn n"><?php echo do_shortcode( __( 'Article written by [entry-author]', 'outline' ) ); ?></h4>

		<?php echo get_avatar( get_the_author_meta( 'user_email' ), '96' ); ?>

		<div class="author-description author-bio">
			<?php the_author_meta( 'description' ); ?>
		</div>

		<?php if ( get_the_author_meta( 'Twitter' ) ) { ?>
			<p class="twitter clear">
				<a href="http://twitter.com/<?php the_author_meta( 'twitter' ); ?>" title="<?php printf( esc_attr__( 'Follow %1$s on Twitter', 'outline' ), get_the_author_meta( 'display_name' ) ); ?>"><?php printf( __( 'Follow %1$s on Twitter', 'outline' ), get_the_author_meta( 'display_name' ) ); ?></a>
			</p>
		<?php } // End check for twitter ?>
	</div><?php
}

?>